#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-random
version:              1.5.0.1
visibility:           public
id:                   generic-random-1.5.0.1-9XCeCfNNqAx6gGuFe9A8C0
key:                  generic-random-1.5.0.1-9XCeCfNNqAx6gGuFe9A8C0
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  dde356184840f421b4b4cf01c46fa132
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.DerivingVia
    Generic.Random.Internal.BaseCase Generic.Random.Internal.Generic
    Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.6.6/site-local/generic-random-1.5.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/generic-random-1.5.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/generic-random-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-random
hs-libraries:         HSgeneric-random-1.5.0.1-9XCeCfNNqAx6gGuFe9A8C0
depends:
    QuickCheck-2.15.0.1-K0JFHgomBHu3hU8T85EWwT base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

